==> xld-utils-22.1.11-sources.jar: com/xebialabs/deployit/core/util/CollectionUtil.java <==
package com.xebialabs.deployit.core.util;

import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.function.Function;
import java.util.stream.Collectors;

import static java.util.stream.Collectors.*;
import static java.util.stream.Collectors.toMap;

public final class CollectionUtil {

    private CollectionUtil() {}

    public static Set<ConfigurationItem> resolve(Set<Integer> values, Function<? super Integer, ? extends ConfigurationItem> resolver) {
        return values.stream().map(resolver).collect(toSet());
    }

    public static List<ConfigurationItem> resolve(List<Integer> values, Function<? super Integer, ? extends ConfigurationItem> resolver) {
        return values.stream().map(resolver).collect(toList());
    }

    public static Map<String, String> toMap(List<Map<String, Object>> results, String key, String value) {
        return results.stream().collect(Collectors.toMap(map -> (String) map.get(key), map -> (String) map.get(value)));
    }

    public static <S, T> Set<T> apply(Set<S> values, Function<? super S, T> func) {
        return values.stream().map(func).collect(toSet());
    }

    public static <S, T> List<T> apply(List<S> values, Function<? super S, T> func) {
        return values.stream().map(func).collect(toList());
    }

    public static <S, T> Map<String, T> apply(Map<String, S> values, Function<? super S, T> func) {
        return values.entrySet().stream().collect(Collectors.toMap(Map.Entry::getKey, entry -> func.apply(entry.getValue())));
    }
}

==> xld-utils-25.1.0-514.439-sources.jar: com/xebialabs/deployit/core/util/CollectionUtil.java <==
package com.xebialabs.deployit.core.util;

import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.function.Function;
import java.util.stream.Collectors;

import static java.util.stream.Collectors.toList;
import static java.util.stream.Collectors.toSet;

public final class CollectionUtil {

    private CollectionUtil() {}

    public static Set<ConfigurationItem> resolve(Set<Integer> values, Function<? super Integer, ? extends ConfigurationItem> resolver) {
        return values.stream().map(resolver).collect(toSet());
    }

    public static List<ConfigurationItem> resolve(List<Integer> values, Function<? super Integer, ? extends ConfigurationItem> resolver) {
        return values.stream().map(resolver).collect(toList());
    }

    public static Map<String, String> toMap(List<Map<String, Object>> results, String key, String value) {
        return results.stream().collect(Collectors.toMap(map -> (String) map.get(key), map -> (String) map.get(value)));
    }

    public static <S, T> Set<T> apply(Set<S> values, Function<? super S, T> func) {
        return values.stream().map(func).collect(toSet());
    }

    public static <S, T> List<T> apply(List<S> values, Function<? super S, T> func) {
        return values.stream().map(func).collect(toList());
    }

    public static <S, T> Map<String, T> apply(Map<String, S> values, Function<? super S, T> func) {
        return values.entrySet().stream().collect(Collectors.toMap(Map.Entry::getKey, entry -> func.apply(entry.getValue())));
    }
}
